@@ -7,6 +7,7 @@ from cloudscraper import CloudScraper
 from typing import Optional, Union
 
 from . import aterrors
+from . import atjsparse
 
 REQGET = 0
 REQPOST = 1
@@ -30,10 +31,14 @@ class AternosConnect:
 
 		try:
 			pagehead = pagetree.head
-			self.token = re.search(
-				r'const\s+AJAX_TOKEN\s*=\s*["\'](\w+)["\']',
-				pagehead.text_content()
-			)[1]
+			text = pagehead.text_content()
+
+			js_code = re.findall(r'\(\(\)(.*?)\)\(\);', text)
+			token_func = js_code[1] if len(js_code) > 1 else js_code[0]
+
+			ctx = atjsparse.exec(token_func)
+			self.token = ctx.window['AJAX_TOKEN']
+
 		except (IndexError, TypeError):
 			raise aterrors.AternosCredentialsError(
 				'Unable to parse TOKEN from the page'
@@ -144,5 +149,5 @@ class AternosConnect:
 					cookies=reqcookies
 				)
 			countdown -= 1
-
+			
 		return req
